@@ -33,7 +33,8 @@ def get_consumer(queue_name, *, consuming_function: Callable = None, function_ti
     :param specify_threadpool:使用指定的线程池（协程池），可以多个消费者共使用一个线程池，不为None时候。threads_num失效
     :param concurrent_mode:并发模式，1线程 2gevent 3eventlet
     :param max_retry_times: 最大自动重试次数，当函数发生错误，立即自动重试运行n次，对一些特殊不稳定情况会有效果。
-    可以在函数中主动抛出重试的异常ExceptionForRetry，框架也会立即自动重试。 主动抛出ExceptionForRequeue异常，则当前消息会重返中间件。
+           可以在函数中主动抛出重试的异常ExceptionForRetry，框架也会立即自动重试。
+           主动抛出ExceptionForRequeue异常，则当前消息会重返中间件。
     :param log_level:框架的日志级别。
     :param is_print_detail_exception:是否打印详细的堆栈错误。为0则打印简略的错误占用控制台屏幕行数少。
     :param msg_schedule_time_intercal:消息调度的时间间隔，用于控频的关键。
@@ -45,10 +46,11 @@ def get_consumer(queue_name, *, consuming_function: Callable = None, function_ti
     :param is_do_not_run_by_specify_time_effect :是否使不运行的时间段生效
     :param do_not_run_by_specify_time   :不运行的时间段
     :param schedule_tasks_on_main_thread :直接在主线程调度任务，意味着不能直接在当前主线程同时开启两个消费者。
-    :param function_result_status_persistance_conf   :配置。是否保存函数的入参，运行结果和运行状态到mongodb。这一步用于后续的参数追溯，
-           任务统计和web展示，需要安装mongo。
-    :param broker_kind:中间件种类,。 0 使用pika链接rabbitmqmq，1使用rabbitpy包实现的操作rabbitmnq，2使用redis，3使用python内置Queue,
-           4使用amqpstorm包实现的操作rabbitmq，5使用mongo，6使用sqlite。7使用nsq，8使用kafka，9也是使用redis但支持消费确认。
+    :param function_result_status_persistance_conf   :配置。是否保存函数的入参，运行结果和运行状态到mongodb。
+           这一步用于后续的参数追溯，任务统计和web展示，需要安装mongo。
+    :param broker_kind:中间件种类,。 0 使用pika链接rabbitmqmq，1使用rabbitpy包实现的操作rabbitmnq，2使用redis，
+           3使用python内置Queue,4使用amqpstorm包实现的操作rabbitmq，5使用mongo，6使用sqlite。
+           7使用nsq，8使用kafka，9也是使用redis但支持消费确认。
     :return AbstractConsumer
     """
     all_kwargs = copy.copy(locals())
